import re
from datetime import datetime
from typing import Optional, Union, List

from pydantic import BaseModel, EmailStr, field_validator, ConfigDict, Field


class TransactionBase(BaseModel):
    """Base schema for transactions"""

    id: str
    user_id: str
    token_id: str
    amount: float
    transaction_type: str 
    status: str 
    #Field("'pending'", description="Transaction status")
    address: str
    transaction_hash: str
    created_at: datetime
    updated_at: datetime

    @staticmethod
    def format_date(value: datetime):
        return value.strftime("%b %d, %Y") if value else None
    
    def dict(self, *args, **kwargs):
        data = super().dict(*args, **kwargs)
        data["created_at"] = self.format_date(self.created_at)
        data["updated_at"] = self.format_date(self.updated_at)
        
        return data

    model_config = ConfigDict(from_attributes=True)


class TransactionCreate(BaseModel):
    """Schema to create a new transaction"""

    user_id: str
    token_id: str
    amount: float
    transaction_type: str  # Deposit or Withdrawal



class TransactionData(BaseModel):
    """Schema to return transaction data"""

    id: str
    user_id: str
    token_id: str
    amount: float
    transaction_type: str
    status: str
    created_at: datetime
    updated_at: datetime

    model_config = ConfigDict(from_attributes=True)